@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -33,9 +33,9 @@ You supply the SQL statements in `spec`. `spec` is a hash which contains the key
 from nothing). It should be the SQL statements to create the latest version of
 the schema.
 
-There should also be zero or more `upgrade_to_v$VER` keys, the value of each is
-a series of SQL statements to upgrade from ($VER-1) to $VER. So there could be
-`upgrade_to_v2`, `upgrade_to_v3`, and so on up the latest version.
+There should also be zero or more `upgrade_to_v$VERSION` keys, the value of each
+is a series of SQL statements to upgrade from ($VERSION-1) to $VERSION. So there
+could be `upgrade_to_v2`, `upgrade_to_v3`, and so on up the latest version.
 
 This routine will connect to database and check the current schema version. If
 `meta` table does not exist yet, the SQL statements in `install` will be
@@ -43,10 +43,13 @@ executed. The `meta` table will also be created and a row ('schema_version', 1)
 is added.
 
 If `meta` table already exists, schema version will be read from it and one or
-more series of SQL statements from `upgrade_to_v$VER` will be executed to bring
-the schema to the latest version.
+more series of SQL statements from `upgrade_to_v$VERSION` will be executed to
+bring the schema to the latest version.
 
-Currently only tested on MySQL, Postgres, and SQLite.
+Currently only tested on MySQL, Postgres, and SQLite. Postgres is recommended
+because it can do transactional DDL (a failed upgrade in the middle will not
+cause the database schema state to be inconsistent, e.g. in-between two
+versions).
 
 _
     args => {
@@ -173,7 +176,38 @@ SHARYANTO::SQL::Schema - Routine and convention to create/update your applicatio
 
 =head1 VERSION
 
-version 0.04
+version 0.05
+
+=head1 DESCRIPTION
+
+This module uses L<Log::Any> for logging.
+
+To use this module, you typically run the create_or_update_db_schema() routine
+at the start of your program/script, e.g.:
+
+ use DBI;
+ use SHARYANTO::SQL::Schema qw(create_or_update_db_schema);
+ my $spec = {...}; # the schema specification
+ my $dbh = DBI->connect(...);
+ my $res = create_or_update_db_schema(dbh=>$dbh, spec=>$spec);
+
+This way, your program automatically creates/updates database schema when run.
+Users need not know anything.
+
+=head1 SEE ALSO
+
+Some other database migration tools that directly uses SQL:
+
+=over
+
+=item * L<Database::Migrator>
+
+Pretty much similar, albeit more fully-fledged/involved. You have to use OO
+style. You put each version's SQL in a separate file and subdirectory. Perl
+scripts can also be executed for each version upgrade. Meta table is
+configurable (default recommended is 'AppliedMigrations').
+
+=back
 
 =head1 DESCRIPTION
 
@@ -203,9 +237,9 @@ C<install> (the value of which is a series of SQL statements to create the schem
 from nothing). It should be the SQL statements to create the latest version of
 the schema.
 
-There should also be zero or more C<upgrade_to_v$VER> keys, the value of each is
-a series of SQL statements to upgrade from ($VER-1) to $VER. So there could be
-C<upgrade_to_v2>, C<upgrade_to_v3>, and so on up the latest version.
+There should also be zero or more C<upgrade_to_v$VERSION> keys, the value of each
+is a series of SQL statements to upgrade from ($VERSION-1) to $VERSION. So there
+could be C<upgrade_to_v2>, C<upgrade_to_v3>, and so on up the latest version.
 
 This routine will connect to database and check the current schema version. If
 C<meta> table does not exist yet, the SQL statements in C<install> will be
@@ -213,10 +247,13 @@ executed. The C<meta> table will also be created and a row ('schema_version', 1)
 is added.
 
 If C<meta> table already exists, schema version will be read from it and one or
-more series of SQL statements from C<upgrade_to_v$VER> will be executed to bring
-the schema to the latest version.
+more series of SQL statements from C<upgrade_to_v$VERSION> will be executed to
+bring the schema to the latest version.
 
-Currently only tested on MySQL, Postgres, and SQLite.
+Currently only tested on MySQL, Postgres, and SQLite. Postgres is recommended
+because it can do transactional DDL (a failed upgrade in the middle will not
+cause the database schema state to be inconsistent, e.g. in-between two
+versions).
 
 Arguments ('*' denotes required arguments):
 
